Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(80)

Unified Diff: chromeos/dbus/auth_policy_client.h

Issue 2835473002: Chromad: Allow offline login. (Closed)
Patch Set: Add TryAuthenticateUser call Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/webui/chromeos/login/gaia_screen_handler.cc ('k') | chromeos/dbus/auth_policy_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/dbus/auth_policy_client.h
diff --git a/chromeos/dbus/auth_policy_client.h b/chromeos/dbus/auth_policy_client.h
index 4eb76e277a6071905db854c2d11153bbc165689b..9e0bb1f5cb3baeb8a969cdce286e43f62a6549e3 100644
--- a/chromeos/dbus/auth_policy_client.h
+++ b/chromeos/dbus/auth_policy_client.h
@@ -49,10 +49,13 @@ class CHROMEOS_EXPORT AuthPolicyClient : public DBusClient {
JoinCallback callback) = 0;
// Calls AuthenticateUser. It runs "kinit <user_principal_name> .. " which
// does kerberos authentication against Active Directory server.
// |password_fd| is similar to the one in the JoinAdDomain.
// |callback| is called after getting (or failing to get) D-BUS response.
virtual void AuthenticateUser(const std::string& user_principal_name,
+ const std::string& object_guid,
int password_fd,
AuthCallback callback) = 0;
« no previous file with comments | « chrome/browser/ui/webui/chromeos/login/gaia_screen_handler.cc ('k') | chromeos/dbus/auth_policy_client.cc » ('j') | no next file with comments »
@@ -49,10 +49,13 @@ class CHROMEOS_EXPORT AuthPolicyClient : public DBusClient {
JoinCallback callback) = 0;
// Calls AuthenticateUser. It runs "kinit <user_principal_name> .. " which
- // does kerberos authentication against Active Directory server.
- // |password_fd| is similar to the one in the JoinAdDomain.
- // |callback| is called after getting (or failing to get) D-BUS response.
+ // does kerberos authentication against Active Directory server. If
+ // |object_guid| is not empty authpolicy service first does ldap search by
+ // that |object_guid| for samAccountName and uses it for kinit. |password_fd|
+ // is similar to the one in the JoinAdDomain. |callback| is called after
+ // getting (or failing to get) D-BUS response.
virtual void AuthenticateUser(const std::string& user_principal_name,

Powered by Google App Engine
This is Rietveld 408576698